Interoperability between Python and Gmsh
========================================

.. image:: https://gitlab.tiker.net/inducer/gmsh_interop/badges/main/pipeline.svg
    :alt: Gitlab Build Status
    :target: https://gitlab.tiker.net/inducer/gmsh_interop/commits/main
.. image:: https://github.com/inducer/gmsh_interop/actions/workflows/ci.yml/badge.svg
    :alt: Github Build Status
    :target: https://github.com/inducer/gmsh_interop/actions/workflows/ci.yml
.. image:: https://badge.fury.io/py/gmsh_interop.svg
    :alt: Python Package Index Release Page
    :target: https://pypi.org/project/gmsh_interop/
.. image:: https://zenodo.org/badge/113488057.svg
   :alt: Zenodo DOI for latest release
   :target: https://zenodo.org/doi/10.5281/zenodo.11075135

This package allows Python to interoperate with the `gmsh <http://gmsh.info/>`__
mesh generator.

This package contains:

* ``gmsh_interop.reader`` to read gmsh's ``.msh`` file format.
* ``gmsh_interop.runner`` to run gmsh under program control and process its output.

Its contents was extracted from `meshpy <https://github.com/inducer/meshpy>`__
to escape its obnoxious licensing.

Links:

* `Github <https://github.com/inducer/gmsh_interop>`__
* `Python Package Index <https://pypi.org/project/gmsh_interop/>`__
* `Documentation <https://documen.tician.de/gmsh_interop>`__
